/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui.prototypes;

import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtils.getAllLocalReuseLibraries;
import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtils.getReuseElementName;

import java.util.List;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.kernel.extension.IPrototypeProvider;
import org.fortiss.tooling.kernel.extension.base.PrototypeProviderBase;

/**
 * {@link IPrototypeProvider} for reuse elements.
 *
 * @author bergemann
 */
public final class PrototypeProvider extends PrototypeProviderBase {

	/**
	 * The default name of the roots of reuse elements, which are
	 * {@link ReuseLibrary}s.
	 */
	public static final String DEFAULT_ROOT_REUSE_ELEMENT_NAME = "Reuse Library";

	/** {@inheritDoc} */
	@Override
	protected void registerPrototypes() {
		List<ReuseLibrary> libraryList = getAllLocalReuseLibraries();
		if (libraryList == null || libraryList.isEmpty()) {
			return;
		}

		// register all elements of all found libraries (and the libraries themselves)
		for (ReuseLibrary library : libraryList) {
			String libraryName = getReuseElementName(library);

			// the library name is also used now as the category name for all contained
			// reuse elements of this library
			registerPrimaryPrototype(libraryName, library, libraryName);

			EList<EObject> reuseElementList = library.getReuseElementList();
			for (EObject libraryElement : reuseElementList) {
				registerPrototype(getReuseElementName(libraryElement), libraryElement, libraryName);
			}
		}
	}
}
